'’Auto Data cleaner - “samoy” samoy is a Python package for\r\nmachine:raw-latex:`\\r`:raw-latex:`\\nlearning `and data science, built on\r\ntop of Pandas inbuilt\r\nlibraries.:raw-latex:`\\r`:raw-latex:`\\nThis `package will be useful for\r\ndata pre-processing before starting\r\noff:raw-latex:`\\r`:raw-latex:`\\nany `machine learning or data science\r\nproject as it will ease your\r\nentire:raw-latex:`\\r`:raw-latex:`\\nprocess `of data cleaning without\r\nmuch input from the user. This\r\nproject:raw-latex:`\\r`:raw-latex:`\\nis `developed in July,2020 by a team\r\nof post graduate students and\r\nsince:raw-latex:`\\r`:raw-latex:`\\nthen `many have also contributed. It\r\nis currently maintained by the same:raw-latex:`\\r`:raw-latex:`\\nteam`.\r\nInstallation Dependencies samoy requires: • Python (>= 3.6)\r\n•:raw-latex:`\\r`:raw-latex:`\\nNumPy `(>= 1.13.3) • pandas (>=1.1.0) User\r\ninstallation If you already:raw-latex:`\\r`:raw-latex:`\\nhave `a working\r\ninstallation of numpy and pandas, the easiest way\r\nto:raw-latex:`\\r`:raw-latex:`\\ninstall `samoy is using pip pip install\r\nsamoy Package Utilities In:raw-latex:`\\r`:raw-latex:`\\ncurrent `version\r\nof this package it only handles missing,null values\r\nand:raw-latex:`\\r`:raw-latex:`\\nduplicates `along with case conversion\r\nUtilities supported: • Null\r\nvalues:raw-latex:`\\r`:raw-latex:`\\nhandeling `: Dropping and\r\nimputing(with mean,median as well as\r\ncustom:raw-latex:`\\r`:raw-latex:`\\nvalues`) • Imputing null values with\r\nthe threshold as mentioned by the:raw-latex:`\\r`:raw-latex:`\\nuser `in\r\nterms of percentage • Missing values handeling : Dropping\r\nand:raw-latex:`\\r`:raw-latex:`\\nimputing`(with mean,median and LRU) •\r\nDuplicates removal • Case:raw-latex:`\\r`:raw-latex:`\\nconversion `like\r\nif use wants to convert specific columns or\r\nentire:raw-latex:`\\r`:raw-latex:`\\ncolumn `values into either lower or\r\nupper case Name of functions\r\nprovided:raw-latex:`\\r`:raw-latex:`\\nin `this package: 1. Handeling Null\r\no dropnull : This function will\r\ndrop:raw-latex:`\\r`:raw-latex:`\\nnull `in three ways that is dropping\r\nall null in the entire:raw-latex:`\\r`:raw-latex:`\\ndataframe`,dropping\r\ncolumns or rows having all nulls and dropping\r\nthe:raw-latex:`\\r`:raw-latex:`\\nrows `or columns having any of the value\r\nas null and return the\r\ndataframe:raw-latex:`\\r`:raw-latex:`\\nafter `removing null by the method\r\nas mentioned by user. By default\r\nit:raw-latex:`\\r`:raw-latex:`\\ndrops `all the null if no method is\r\nmentioned explicitely. o dropnull_th:raw-latex:`\\r`:raw-latex:`\\n`: This\r\nfunction will drop the nulls in those columns where the number\r\nof:raw-latex:`\\r`:raw-latex:`\\nnulls `is greater than or equal to the\r\npercentage specified by the\r\nuser:raw-latex:`\\r`:raw-latex:`\\nand `returns dataframe having nulls\r\ndropped in those columns where\r\nnumber:raw-latex:`\\r`:raw-latex:`\\nof `null is greater than the\r\npercentage(mentioned by user while\r\ncalling:raw-latex:`\\r`:raw-latex:`\\nfunction`) of total number of\r\nrecords in that column. o swapnull :\r\nThis:raw-latex:`\\r`:raw-latex:`\\nfunction `will replace all the null\r\nvalues with the three\r\ndifferent:raw-latex:`\\r`:raw-latex:`\\nmethods `like custom method,mean\r\nand median and it will return\r\nthe:raw-latex:`\\r`:raw-latex:`\\ndataframe `having all null values\r\nreplaced by the method as chosen by\r\nthe:raw-latex:`\\r`:raw-latex:`\\nuser`.By default if nothing is mentioned\r\nexplicitely,it will impute nulls:raw-latex:`\\r`:raw-latex:`\\nwith `the\r\nmean value. o swapnull_subset : This function will replace\r\nall:raw-latex:`\\r`:raw-latex:`\\nthe `null values in the columns as\r\nspecified by the user with the\r\nthree:raw-latex:`\\r`:raw-latex:`\\ndifferent `methods like custom\r\nmethod,mean and median and it will\r\nreturn:raw-latex:`\\r`:raw-latex:`\\nthe `dataframe having all null values\r\nreplaced in the selected columns\r\nby:raw-latex:`\\r`:raw-latex:`\\nthe `method as chosen by the user.By\r\ndefault if nothing is\r\nmentioned:raw-latex:`\\r`:raw-latex:`\\nexplicitely`,it will impute nulls\r\nwith the mean value. 2. Handeling:raw-latex:`\\r`:raw-latex:`\\nMissing `o\r\nswapmissing : This function replace NaN values with mean\r\nor:raw-latex:`\\r`:raw-latex:`\\nmedian `of the specific column. If user\r\nmention method as mean or median:raw-latex:`\\r`:raw-latex:`\\nit `will\r\npick it as it is and if user dont want to mention any\r\nmethod:raw-latex:`\\r`:raw-latex:`\\nthen `by default mean value to be\r\nreplaced. o swapmissing_subset :\r\nThis:raw-latex:`\\r`:raw-latex:`\\nfunction `replace NaN values with mean\r\nor median in the specific\r\nnumeric:raw-latex:`\\r`:raw-latex:`\\ncolumns `only. If user mentions any\r\nmethod like mean or median it will:raw-latex:`\\r`:raw-latex:`\\npick `it\r\nas it is and if user dont want to mention any method then\r\nby:raw-latex:`\\r`:raw-latex:`\\ndefault `missing value will be replaced\r\nto mean value. o swapmissing_lru:raw-latex:`\\r`:raw-latex:`\\n`: This\r\nfunction will replace the NaN value with last and next value\r\nof:raw-latex:`\\r`:raw-latex:`\\nthe `same column and if there are many\r\nNaN values with start of the:raw-latex:`\\r`:raw-latex:`\\ncolumn `then it\r\nwill start replacing same with mean of the same column.\r\no:raw-latex:`\\r`:raw-latex:`\\ndropmissing `: This function drops missing\r\nvalues from the given data.\r\no:raw-latex:`\\r`:raw-latex:`\\ndropmissing`\\_rows : This function drops\r\nrows whose all values are:raw-latex:`\\r`:raw-latex:`\\nmissing`. o\r\ndropmissing_subset : This function drops missing values\r\nas:raw-latex:`\\r`:raw-latex:`\\nwell `as NaN values from the selcted\r\ncolumns of the dataframe\r\n3.:raw-latex:`\\r`:raw-latex:`\\nHandeling `Duplicates o\r\ndrop_replicatecols : This function will\r\ndrop:raw-latex:`\\r`:raw-latex:`\\nduplicate `columns and return the\r\ndataframe after dropping the\r\ncolumns:raw-latex:`\\r`:raw-latex:`\\nhaving `same name(names are also\r\ntypographically matched with respect\r\nto:raw-latex:`\\r`:raw-latex:`\\nupper `or lower case). o drop_replicates\r\n: This function drops duplicate:raw-latex:`\\r`:raw-latex:`\\nrows `that\r\nare present in enitre column of dataframe or within the\r\nsubset:raw-latex:`\\r`:raw-latex:`\\nof `columns as specifies by users. 4.\r\nCase conversion o altercase :\r\nThis:raw-latex:`\\r`:raw-latex:`\\nfunction `is usually to convert the\r\ncontent of dataframe either in\r\nlower:raw-latex:`\\r`:raw-latex:`\\ncase `or upper case. o\r\naltercase_subset : This function is usually\r\nto:raw-latex:`\\r`:raw-latex:`\\nconvert `the content of only selected\r\ncolumns either in lower case or:raw-latex:`\\r`:raw-latex:`\\nupper `case\r\nand returns dataframe having the content of mentioned\r\ncolumns:raw-latex:`\\r`:raw-latex:`\\neither `in lower or upper case.\r\nDetails of each functions To know\r\nthe:raw-latex:`\\r`:raw-latex:`\\ndetailed `summary of each function along\r\nwith its parameters and a demo:raw-latex:`\\r`:raw-latex:`\\nexample `to\r\nuse it,please use command help(name_of_function) Contact\r\nUs::raw-latex:`\\r`:raw-latex:`\\nEmail`:\r\nsamoyapi@gmail.com:raw-latex:`\\r`:raw-latex:`\\n`’\r\n'